summaryrefslogtreecommitdiffhomepage
path: root/pkg/p9/p9.go
diff options
context:
space:
mode:
authorgVisor bot <gvisor-bot@google.com>2021-03-23 22:57:57 +0000
committergVisor bot <gvisor-bot@google.com>2021-03-23 22:57:57 +0000
commit36211dedcc236309759ea793e2fb5d7fbedbd848 (patch)
treebdb4bfce94edb02cbc4927b3f35fab6a99911585 /pkg/p9/p9.go
parente48ad2ada0357cb8ee9185074aaff7ab44d84631 (diff)
parent92374e51976c8a47e4705943f73cecbc6a27073b (diff)
Merge release-20210315.0-16-g92374e519 (automated)
Diffstat (limited to 'pkg/p9/p9.go')
-rw-r--r--pkg/p9/p9.go11
1 files changed, 9 insertions, 2 deletions
diff --git a/pkg/p9/p9.go b/pkg/p9/p9.go
index 2235f8968..648cf4b49 100644
--- a/pkg/p9/p9.go
+++ b/pkg/p9/p9.go
@@ -151,9 +151,16 @@ const (
// Sticky is a mode bit indicating sticky directories.
Sticky FileMode = 01000
+ // SetGID is the set group ID bit.
+ SetGID FileMode = 02000
+
+ // SetUID is the set user ID bit.
+ SetUID FileMode = 04000
+
// permissionsMask is the mask to apply to FileModes for permissions. It
- // includes rwx bits for user, group and others, and sticky bit.
- permissionsMask FileMode = 01777
+ // includes rwx bits for user, group, and others, as well as the sticky
+ // bit, setuid bit, and setgid bit.
+ permissionsMask FileMode = 07777
)
// QIDType is the most significant byte of the FileMode word, to be used as the